@@ -1,5 +1,11 @@
 from django.conf import settings
-from django.http import HttpResponseRedirect, get_host
+from django.http import HttpResponseRedirect
+
+try:
+    from django.http import get_host
+    use_request_for_host = False
+except:
+    use_request_for_host = True
 
 SSL = 'SSL'
 
@@ -16,7 +22,10 @@ class SSLRedirect:
 			
 	def _redirect(self, request, secure):
 		protocol = secure and "https" or "http"
-		newurl = "%s://%s%s" % (protocol, get_host(request), request.get_full_path())
+        if use_request_for_host:
+            newurl = "%s://%s%s" % (protocol, request.get_host(), request.get_full_path())
+        else:
+            newurl = "%s://%s%s" % (protocol, get_host(request), request.get_full_path())
 		return HttpResponseRedirect(newurl)
 
 
@@ -29,5 +38,8 @@ class WWWRedirect:
 
 	def _redirect(self, request, secure):
 		protocol = secure and "https" or "http"
-		newurl = "%s://%s.%s%s" % (protocol, 'www', get_host(request), request.get_full_path())
+        if use_request_for_host:
+            newurl = "%s://%s.%s%s" % (protocol, 'www', request.get_host(), request.get_full_path())
+        else:
+            newurl = "%s://%s.%s%s" % (protocol, 'www', get_host(request), request.get_full_path())
 		return HttpResponseRedirect(newurl)
\ No newline at end of file
